@@ -25,7 +25,6 @@
 #define _SHARE_SETTINGS_H
 
 #include <gtk/gtkwidget.h>
-#include "share-export.h"
 
 enum {
 	SHARE_DONT_SHARE,
@@ -33,9 +32,13 @@ enum {
 	SHARE_THROUGH_NFS
 };
 
+void          share_settings_set_name_from_folder (void);
 void          share_settings_dialog_run        (const gchar*, gboolean);
 void          share_settings_create_combo      (void);
+gboolean      share_settings_validate          (void);
 
 void          smb_settings_prepare_dialog      (void);
 void          smb_settings_save                (void);
+
+
 #endif /* _SHARE_SETTINGS_H */
